# Step 5: Create a Rationalization Roadmap
### On this page
  * [Prepare Initiatives for Your Roadmap](https://help.sap.com/docs/leanix/ea/application-rationalization-create-roadmap#prepare-initiatives-for-your-roadmap)
  * [View the Roadmap](https://help.sap.com/docs/leanix/ea/application-rationalization-create-roadmap#view-the-roadmap)


Organize, link, and visualize rationalization projects and their dependencies to align with business strategy, and leverage reports for transparent project management.
Now that you understand the priorities and dependencies, you can start building your roadmap for the application rationalization. This is a project management task that helps you understand and visualize the timeline of your rationalization initiative.
Depending on the size of the planned rationalization, you can create a program that can be detailed into several projects or initiatives. Alternatively, you can divide a larger project into sub-projects. This approach enables you to manage initiatives sequentially. For example, you can prioritize applications that are quick wins because they have low business criticality or few dependencies. Working with smaller initiatives allows you to present results to management and business stakeholders early and integrate lessons learned into subsequent initiatives.
The roadmap report can be used to easily visualize and show the initiatives and their timeline using initiative fact sheets.
